# GoogleSearchconsoleApp MCP Server

An MCP Server for the GoogleSearchconsoleApp API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the GoogleSearchconsoleApp API.


| Tool | Description |
|------|-------------|
| `get_sitemap` | Retrieves information about a specific sitemap. |
| `list_sitemaps` | Lists the sitemaps-entries submitted for this site, or included in the sitemap index file  |
| `submit_sitemap` | Submits a sitemap for a site. Typically returns HTTP 204 No Content on success. |
| `delete_sitemap` | Deletes a sitemap from this site. Typically returns HTTP 204 No Content on success. |
| `get_site` | Retrieves information about a specific site. |
| `list_sites` | Lists the user's Search Console sites. |
| `add_site` | Adds a site to the set of the user's sites in Search Console. |
| `delete_site` | Removes a site from the set of the user's Search Console sites. |
| `index_inspect_url` | Inspects a URL in Google Index and provides information about its status. |
| `query_search_analytics` | Queries your search traffic data with filters and parameters that you define. |
